==> nextcloud-app-spreed-1%3A9.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/zh_TW.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "交談",
    "Guest" : "訪客",
    "You started a call" : "您打了一通電話",
    "Open settings" : "開啟設定",
    "Andorra" : "安道爾",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安提瓜和巴布達",
    "Anguilla" : "安圭拉",
    "Albania" : "阿爾巴尼亞",
    "Armenia" : "亞美尼亞",
    "Angola" : "安哥拉",
    "Antarctica" : "南極地區",
    "Argentina" : "阿根廷",
    "American Samoa" : "美屬薩摩亞",
    "Austria" : "奧地利",
    "Australia" : "澳大利亞",
    "Aruba" : "阿路巴",
    "Azerbaijan" : "亞塞拜然",
    "Bosnia and Herzegovina" : "波希尼亞及赫塞哥維那",
    "Barbados" : "巴貝多",
    "Bangladesh" : "孟加拉",
    "Belgium" : "比利時",
    "Burkina Faso" : "有吉納法索",
    "Bulgaria" : "保加利亞",
    "Bahrain" : "巴林",
    "Burundi" : "蒲隆地",
    "Benin" : "貝南",
    "Bermuda" : "百慕達",
    "Brunei Darussalam" : "汶萊",
    "Bonaire, Sint Eustatius and Saba" : "荷蘭加勒比區",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈馬",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布威島",
    "Botswana" : "波札那",
    "Belarus" : "白俄羅斯",
    "Belize" : "貝里斯",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯(基林)群島",
    "Central African Republic" : "中非共和國",
    "Congo" : "剛果",
    "Switzerland" : "瑞士",
    "Cook Islands" : "科克群島",
    "Chile" : "智利",
    "Cameroon" : "喀麥隆",
    "China" : "中國大陸",
    "Colombia" : "哥倫比亞",
    "Costa Rica" : "哥斯大黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "維德角共和國",
    "Christmas Island" : "聖誕島領地",
    "Cyprus" : "塞浦路斯",
    "Czechia" : "捷克",
    "Germany" : "德國",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麥",
    "Dominica" : "多米尼克",
    "Dominican Republic" : "多明尼加",
    "Algeria" : "阿爾及利亞",
    "Ecuador" : "厄瓜多爾",
    "Estonia" : "愛沙尼亞",
    "Egypt" : "埃及",
    "Eritrea" : "厄利垂亞",
    "Spain" : "西班牙",
    "Ethiopia" : "衣索匹亞",
    "Finland" : "芬蘭",
    "Fiji" : "斐濟",
    "Falkland Islands (Malvinas)" : "福克蘭群島",
    "Faroe Islands" : "法羅群島",
    "France" : "法國",
    "Gabon" : "加彭",
    "Grenada" : "格瑞那達",
    "Georgia" : "喬治亞",
    "French Guiana" : "法屬圭亞那",
    "Guernsey" : "根西",
    "Ghana" : "迦納",
    "Gibraltar" : "直布羅陀",
    "Greenland" : "格陵蘭",
    "Gambia" : "岡比亞",
    "Guinea" : "幾內亞",
    "Guadeloupe" : "瓜德羅普",
    "Equatorial Guinea" : "幾內亞",
    "Greece" : "希臘",
    "South Georgia and the South Sandwich Islands" : "南喬治亞與南桑威奇",
    "Guatemala" : "瓜地馬拉",
    "Guam" : "關島",
    "Guinea-Bissau" : "幾內亞比索",
    "Guyana" : "蓋亞那",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德島和麥克唐納群島",
    "Honduras" : "宏都拉斯",
    "Croatia" : "克羅埃西亞",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印尼",
    "Ireland" : "愛爾蘭",
    "Israel" : "以色列",
    "Isle of Man" : "曼島",
    "India" : "印度",
    "British Indian Ocean Territory" : "英屬印度洋屬地",
    "Iraq" : "伊拉克",
    "Iceland" : "冰島",
    "Italy" : "義大利",
    "Jersey" : "澤西",
    "Jamaica" : "牙買加",
    "Jordan" : "約旦",
    "Japan" : "日本",
    "Kenya" : "肯亞",
    "Kyrgyzstan" : "吉爾吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "基里巴斯共和國",
    "Comoros" : "科摩羅",
    "Saint Kitts and Nevis" : "聖克里斯多福及尼維斯",
    "Kuwait" : "科威特",
    "Cayman Islands" : "開曼群島",
    "Kazakhstan" : "哈薩克",
    "Lao People's Democratic Republic" : "寮國",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "聖露西亞",
    "Liechtenstein" : "列支敦士登",
    "Sri Lanka" : "斯里蘭卡",
    "Liberia" : "賴比瑞亞",
    "Lesotho" : "賴索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "盧森堡",
    "Latvia" : "拉脫維亞",
    "Libya" : "利比亞",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩納哥",
    "Montenegro" : "蒙特內哥羅",
    "Saint Martin (French part)" : "聖馬丁島(法國)",
    "Madagascar" : "馬達加斯加",
    "Marshall Islands" : "馬紹爾群島",
    "Mali" : "馬利",
    "Myanmar" : "緬甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳門",
    "Northern Mariana Islands" : "北馬里亞納群島",
    "Martinique" : "馬丁尼克",
    "Mauritania" : "茅利塔尼亞",
    "Montserrat" : "蒙哲臘",
    "Malta" : "馬爾他",
    "Mauritius" : "模里西斯",
    "Maldives" : "馬爾地夫",
    "Malawi" : "馬拉威",
    "Mexico" : "墨西哥",
    "Malaysia" : "馬來西亞",
    "Mozambique" : "莫三鼻克",
    "Namibia" : "納米比亞",
    "New Caledonia" : "新喀里多尼亞",
    "Niger" : "尼日",
    "Norfolk Island" : "諾福克島",
    "Nigeria" : "奈及利亞",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷蘭",
    "Norway" : "挪威",
    "Nepal" : "尼泊爾",
    "Nauru" : "諾魯",
    "Niue" : "紐埃",
    "New Zealand" : "紐西蘭",
    "Oman" : "阿曼",
    "Panama" : "巴拿馬",
    "Peru" : "秘魯",
    "French Polynesia" : "法屬玻里尼西亞",
    "Papua New Guinea" : "巴布亞紐幾內亞",
    "Philippines" : "菲律賓",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波蘭",
    "Saint Pierre and Miquelon" : "聖皮耶與密克隆群島",
    "Pitcairn" : "皮特肯群島",
    "Puerto Rico" : "波多黎各",
    "Palestine, State of" : "巴勒斯坦領土",
    "Portugal" : "葡萄牙",
    "Palau" : "帕勞",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡達",
    "Romania" : "羅馬尼亞",
    "Serbia" : "塞爾維亞",
    "Russian Federation" : "俄羅斯",
    "Rwanda" : "盧安達",
    "Saudi Arabia" : "沙烏地阿拉伯",
    "Solomon Islands" : " 索羅門群島",
    "Seychelles" : "塞席爾",
    "Sudan" : "蘇丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "聖赫勒拿,亞森欣與垂斯坦昆哈",
    "Slovenia" : "斯洛維尼亞",
    "Svalbard and Jan Mayen" : "斯瓦巴和揚馬延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "獅子山共和國",
    "San Marino" : "聖馬力諾",
    "Senegal" : "塞內加爾",
    "Somalia" : "索馬利亞",
    "Suriname" : "蘇利南",
    "South Sudan" : "南蘇丹",
    "Sao Tome and Principe" : "聖多美及普林西比",
    "El Salvador" : "薩爾瓦多",
    "Sint Maarten (Dutch part)" : "荷屬聖馬丁",
    "Syrian Arab Republic" : "敘利亞",
    "Chad" : "查德",
    "French Southern Territories" : "法屬南部和南極領地",
    "Togo" : "多哥",
    "Thailand" : "泰國",
    "Tajikistan" : "塔吉克斯坦",
    "Timor-Leste" : "東帝汶",
    "Taiwan, Province of China" : "台灣,中華民國",
    "Tanzania, United Republic of" : "坦尚尼亞",
    "Holy See" : "聖座",
    "Saint Vincent and the Grenadines" : "聖文森及格瑞那丁",
    "Samoa" : "薩摩亞",
    "Mayotte" : "馬約特",
    "South Africa" : "南非",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Leave call" : "離開通話",
    "Limit to groups" : "限制給特定群組",
    "Everyone" : "所有人",
    "Save changes" : "儲存變更",
    "Saving …" : "儲存中 ...",
    "Saved!" : "已儲存!",
    "None" : "無",
    "User" : "使用者",
    "Disabled" : "停用",
    "Moderators" : "主持人",
    "Users" : "使用者",
    "Beta" : "Beta 測試版",
    "Name" : "名稱",
    "General settings" : "一般設定",
    "Off" : "關閉",
    "Language" : "語言",
    "Country" : "國家",
    "Status" : "狀態",
    "Created at" : "建立於",
    "Pending" : "擱置中",
    "Error" : "錯誤",
    "Blocked" : "已封鎖",
    "Active" : "啟動",
    "Expired" : "已過期",
    "Validate SSL certificate" : "驗證 SSL憑證",
    "Saved" : "儲存",
    "UDP and TCP" : "UDP 和 TCP",
    "UDP only" : "僅UDP",
    "TCP only" : "僅TCP",
    "Copy link" : "複製連結",
    "Dismiss" : "取消",
    "Mute audio (m)" : "靜音 (m)",
    "Mute audio" : "靜音",
    "Disable video" : "停用視訊",
    "You" : "您",
    "Favorite" : "我的最愛",
    "Leave conversation" : "離開對話",
    "Delete conversation" : "刪除對話",
    "Remove from favorites" : "取消我的最愛",
    "Add to favorites" : "加到我的最愛",
    "Loading" : "載入中",
    "Groups" : "群組",
    "Invalid path selected" : "所選的路徑無效",
    "Password protect" : "密碼防護",
    "Back" : "返回",
    "Close" : "關閉",
    "Conversation name" : "對話名稱",
    "Reply" : "回覆",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Send message" : "傳送訊息",
    "File to share" : "要分享的檔案",
    "moderator" : "主持人",
    "guest" : "訪客",
    "No results" : "沒有符合搜尋的項目",
    "Add users or groups" : "增加使用者或者群組",
    "Participants" : "參與者",
    "Chat" : "聊天",
    "Projects" : "專案項目",
    "Settings" : "設定",
    "Edit" : "編輯",
    "Start call" : "通話",
    "Rename conversation" : "重新命名對話",
    "Share link" : "分享連結",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Exit fullscreen (f)" : "離開全螢幕 (f)",
    "Fullscreen (f)" : "全螢幕 (f)",
    "Grid view" : "網格檢視",
    "Join a conversation or start a new one" : "加入一個對話或者開一個新的",
    "Say hi to your friends and colleagues!" : "跟大家打招呼",
    "The password is wrong. Try again." : "密碼錯誤，請重試",
    "Password" : "密碼",
    "Android app" : "安卓應用",
    "iOS app" : "蘋果應用",
    "Enter name for a new conversation" : "輸入新對話名稱",
    "New conversation …" : "新對話",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
    "Room name can not be empty" : "名稱不能空白",
    "Password required" : "請輸入密碼",
    "Cancel" : "取消",
    "Submit" : "送出",
    "Guests" : "訪客",
    "Change password" : "變更密碼",
    "Set password" : "設定密碼",
    "Rename" : "重新命名",
    "Conversation with {name}" : "和 {name} 的談話",
    "No messages yet, start the conversation!" : "尚無訊息，開始對話！",
    "New message …" : "新訊息 ...",
    "Send" : "傳送",
    "Share" : "分享",
    "[Unknown user name]" : "[未知的使用者名稱]",
    "Error while sharing" : "分享時發生錯誤",
    "Share screen" : "分享螢幕",
    "Screensharing is not supported by your browser." : "您的瀏覽器並不支援螢幕分享",
    "Favorited" : "已加入最愛",
    "Limit app usage to groups." : "限制群組的使用率:",
    "Contacts" : "聯絡人"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1%3A10.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/zh_TW.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "交談",
    "Guest" : "訪客",
    "You created the conversation" : "你建立了對話",
    "You started a call" : "您打了一通電話",
    "You left the call" : "你離開了通話",
    "Join call" : "加入通話",
    "Open settings" : "開啟設定",
    "Andorra" : "安道爾",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安提瓜和巴布達",
    "Anguilla" : "安圭拉",
    "Albania" : "阿爾巴尼亞",
    "Armenia" : "亞美尼亞",
    "Angola" : "安哥拉",
    "Antarctica" : "南極地區",
    "Argentina" : "阿根廷",
    "American Samoa" : "美屬薩摩亞",
    "Austria" : "奧地利",
    "Australia" : "澳大利亞",
    "Aruba" : "阿路巴",
    "Azerbaijan" : "亞塞拜然",
    "Bosnia and Herzegovina" : "波希尼亞及赫塞哥維那",
    "Barbados" : "巴貝多",
    "Bangladesh" : "孟加拉",
    "Belgium" : "比利時",
    "Burkina Faso" : "有吉納法索",
    "Bulgaria" : "保加利亞",
    "Bahrain" : "巴林",
    "Burundi" : "蒲隆地",
    "Benin" : "貝南",
    "Bermuda" : "百慕達",
    "Brunei Darussalam" : "汶萊",
    "Bonaire, Sint Eustatius and Saba" : "荷蘭加勒比區",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈馬",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布威島",
    "Botswana" : "波札那",
    "Belarus" : "白俄羅斯",
    "Belize" : "貝里斯",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯(基林)群島",
    "Central African Republic" : "中非共和國",
    "Congo" : "剛果",
    "Switzerland" : "瑞士",
    "Cook Islands" : "科克群島",
    "Chile" : "智利",
    "Cameroon" : "喀麥隆",
    "China" : "中國大陸",
    "Colombia" : "哥倫比亞",
    "Costa Rica" : "哥斯大黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "維德角共和國",
    "Christmas Island" : "聖誕島領地",
    "Cyprus" : "塞浦路斯",
    "Czechia" : "捷克",
    "Germany" : "德國",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麥",
    "Dominica" : "多米尼克",
    "Dominican Republic" : "多明尼加",
    "Algeria" : "阿爾及利亞",
    "Ecuador" : "厄瓜多爾",
    "Estonia" : "愛沙尼亞",
    "Egypt" : "埃及",
    "Eritrea" : "厄利垂亞",
    "Spain" : "西班牙",
    "Ethiopia" : "衣索匹亞",
    "Finland" : "芬蘭",
    "Fiji" : "斐濟",
    "Falkland Islands (Malvinas)" : "福克蘭群島",
    "Faroe Islands" : "法羅群島",
    "France" : "法國",
    "Gabon" : "加彭",
    "Grenada" : "格瑞那達",
    "Georgia" : "喬治亞",
    "French Guiana" : "法屬圭亞那",
    "Guernsey" : "根西",
    "Ghana" : "迦納",
    "Gibraltar" : "直布羅陀",
    "Greenland" : "格陵蘭",
    "Gambia" : "岡比亞",
    "Guinea" : "幾內亞",
    "Guadeloupe" : "瓜德羅普",
    "Equatorial Guinea" : "幾內亞",
    "Greece" : "希臘",
    "South Georgia and the South Sandwich Islands" : "南喬治亞與南桑威奇",
    "Guatemala" : "瓜地馬拉",
    "Guam" : "關島",
    "Guinea-Bissau" : "幾內亞比索",
    "Guyana" : "蓋亞那",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德島和麥克唐納群島",
    "Honduras" : "宏都拉斯",
    "Croatia" : "克羅埃西亞",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印尼",
    "Ireland" : "愛爾蘭",
    "Israel" : "以色列",
    "Isle of Man" : "曼島",
    "India" : "印度",
    "British Indian Ocean Territory" : "英屬印度洋屬地",
    "Iraq" : "伊拉克",
    "Iceland" : "冰島",
    "Italy" : "義大利",
    "Jersey" : "澤西",
    "Jamaica" : "牙買加",
    "Jordan" : "約旦",
    "Japan" : "日本",
    "Kenya" : "肯亞",
    "Kyrgyzstan" : "吉爾吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "基里巴斯共和國",
    "Comoros" : "科摩羅",
    "Saint Kitts and Nevis" : "聖克里斯多福及尼維斯",
    "Kuwait" : "科威特",
    "Cayman Islands" : "開曼群島",
    "Kazakhstan" : "哈薩克",
    "Lao People's Democratic Republic" : "寮國",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "聖露西亞",
    "Liechtenstein" : "列支敦士登",
    "Sri Lanka" : "斯里蘭卡",
    "Liberia" : "賴比瑞亞",
    "Lesotho" : "賴索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "盧森堡",
    "Latvia" : "拉脫維亞",
    "Libya" : "利比亞",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩納哥",
    "Montenegro" : "蒙特內哥羅",
    "Saint Martin (French part)" : "聖馬丁島(法國)",
    "Madagascar" : "馬達加斯加",
    "Marshall Islands" : "馬紹爾群島",
    "Mali" : "馬利",
    "Myanmar" : "緬甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳門",
    "Northern Mariana Islands" : "北馬里亞納群島",
    "Martinique" : "馬丁尼克",
    "Mauritania" : "茅利塔尼亞",
    "Montserrat" : "蒙哲臘",
    "Malta" : "馬爾他",
    "Mauritius" : "模里西斯",
    "Maldives" : "馬爾地夫",
    "Malawi" : "馬拉威",
    "Mexico" : "墨西哥",
    "Malaysia" : "馬來西亞",
    "Mozambique" : "莫三鼻克",
    "Namibia" : "納米比亞",
    "New Caledonia" : "新喀里多尼亞",
    "Niger" : "尼日",
    "Norfolk Island" : "諾福克島",
    "Nigeria" : "奈及利亞",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷蘭",
    "Norway" : "挪威",
    "Nepal" : "尼泊爾",
    "Nauru" : "諾魯",
    "Niue" : "紐埃",
    "New Zealand" : "紐西蘭",
    "Oman" : "阿曼",
    "Panama" : "巴拿馬",
    "Peru" : "秘魯",
    "French Polynesia" : "法屬玻里尼西亞",
    "Papua New Guinea" : "巴布亞紐幾內亞",
    "Philippines" : "菲律賓",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波蘭",
    "Saint Pierre and Miquelon" : "聖皮耶與密克隆群島",
    "Pitcairn" : "皮特肯群島",
    "Puerto Rico" : "波多黎各",
    "Palestine, State of" : "巴勒斯坦領土",
    "Portugal" : "葡萄牙",
    "Palau" : "帕勞",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡達",
    "Romania" : "羅馬尼亞",
    "Serbia" : "塞爾維亞",
    "Russian Federation" : "俄羅斯",
    "Rwanda" : "盧安達",
    "Saudi Arabia" : "沙烏地阿拉伯",
    "Solomon Islands" : " 索羅門群島",
    "Seychelles" : "塞席爾",
    "Sudan" : "蘇丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "聖赫勒拿,亞森欣與垂斯坦昆哈",
    "Slovenia" : "斯洛維尼亞",
    "Svalbard and Jan Mayen" : "斯瓦巴和揚馬延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "獅子山共和國",
    "San Marino" : "聖馬力諾",
    "Senegal" : "塞內加爾",
    "Somalia" : "索馬利亞",
    "Suriname" : "蘇利南",
    "South Sudan" : "南蘇丹",
    "Sao Tome and Principe" : "聖多美及普林西比",
    "El Salvador" : "薩爾瓦多",
    "Sint Maarten (Dutch part)" : "荷屬聖馬丁",
    "Syrian Arab Republic" : "敘利亞",
    "Chad" : "查德",
    "French Southern Territories" : "法屬南部和南極領地",
    "Togo" : "多哥",
    "Thailand" : "泰國",
    "Tajikistan" : "塔吉克斯坦",
    "Timor-Leste" : "東帝汶",
    "Taiwan, Province of China" : "台灣,中華民國",
    "Tanzania, United Republic of" : "坦尚尼亞",
    "Holy See" : "聖座",
    "Saint Vincent and the Grenadines" : "聖文森及格瑞那丁",
    "Samoa" : "薩摩亞",
    "Mayotte" : "馬約特",
    "South Africa" : "南非",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Leave call" : "離開通話",
    "Limit to groups" : "限制給特定群組",
    "Everyone" : "所有人",
    "Save changes" : "儲存變更",
    "Saving …" : "儲存中 ...",
    "Saved!" : "已儲存!",
    "None" : "無",
    "User" : "使用者",
    "Disabled" : "停用",
    "Moderators" : "主持人",
    "Users" : "使用者",
    "Beta" : "Beta 測試版",
    "Name" : "名稱",
    "General settings" : "一般設定",
    "Off" : "關閉",
    "Language" : "語言",
    "Country" : "國家",
    "Status" : "狀態",
    "Created at" : "建立於",
    "Pending" : "擱置中",
    "Error" : "錯誤",
    "Blocked" : "已封鎖",
    "Active" : "啟動",
    "Expired" : "已過期",
    "Validate SSL certificate" : "驗證 SSL憑證",
    "Saved" : "儲存",
    "UDP and TCP" : "UDP 和 TCP",
    "UDP only" : "僅UDP",
    "TCP only" : "僅TCP",
    "Copy link" : "複製連結",
    "Waiting for others to join the call …" : "等待其他人加入通話...",
    "Dismiss" : "取消",
    "Mute audio (m)" : "靜音 (m)",
    "Mute audio" : "靜音",
    "Disable video" : "停用視訊",
    "Back" : "返回",
    "You" : "您",
    "Favorite" : "我的最愛",
    "Leave conversation" : "離開對話",
    "Delete conversation" : "刪除對話",
    "Remove from favorites" : "取消我的最愛",
    "Add to favorites" : "加到我的最愛",
    "Loading" : "載入中",
    "Groups" : "群組",
    "Settings" : "設定",
    "Create a new group conversation" : "建立新群組對話",
    "Password protect" : "密碼防護",
    "Close" : "關閉",
    "Conversation name" : "對話名稱",
    "Allow guests to join via link " : "允許訪客透過連結加入",
    "Camera" : "相機",
    "Reply" : "回覆",
    "Remove" : "移除",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Send message" : "傳送訊息",
    "File to share" : "要分享的檔案",
    "Invalid path selected" : "所選的路徑無效",
    "Enabled" : "已啟用",
    "Save" : "儲存",
    "Password" : "密碼",
    "API token" : "API token",
    "Login" : "帳號",
    "Nickname" : "暱稱",
    "Client ID" : "客戶端ID",
    "moderator" : "主持人",
    "guest" : "訪客",
    "No results" : "沒有符合搜尋的項目",
    "Add users or groups" : "增加使用者或者群組",
    "Participants" : "參與者",
    "Chat" : "聊天",
    "Edit" : "編輯",
    "Keyboard shortcuts" : "快速鍵",
    "Search" : "搜尋",
    "Start call" : "通話",
    "Rename conversation" : "重新命名對話",
    "Share link" : "分享連結",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Exit fullscreen (f)" : "離開全螢幕 (f)",
    "Fullscreen (f)" : "全螢幕 (f)",
    "Grid view" : "網格檢視",
    "Say hi to your friends and colleagues!" : "跟大家打招呼",
    "Start a conversation" : "新對話",
    "Join a conversation or start a new one" : "加入一個對話或者開一個新的",
    "Default" : "預設",
    "The password is wrong. Try again." : "密碼錯誤，請重試",
    "Android app" : "安卓應用",
    "iOS app" : "蘋果應用",
    "Enter name for a new conversation" : "輸入新對話名稱",
    "New conversation …" : "新對話",
    "Projects" : "專案項目",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
    "Room name can not be empty" : "名稱不能空白",
    "Password required" : "請輸入密碼",
    "Cancel" : "取消",
    "Submit" : "送出",
    "Guests" : "訪客",
    "Change password" : "變更密碼",
    "Set password" : "設定密碼",
    "Rename" : "重新命名",
    "Conversation with {name}" : "和 {name} 的談話",
    "No messages yet, start the conversation!" : "尚無訊息，開始對話！",
    "New message …" : "新訊息 ...",
    "Send" : "傳送",
    "Share" : "分享",
    "[Unknown user name]" : "[未知的使用者名稱]",
    "Error while sharing" : "分享時發生錯誤",
    "Waiting for {participantName} to join the call …" : "等待{participantName}加入通話...",
    "Share screen" : "分享螢幕",
    "Screensharing is not supported by your browser." : "您的瀏覽器並不支援螢幕分享",
    "Favorited" : "已加入最愛",
    "Limit app usage to groups." : "限制群組的使用率:",
    "Contacts" : "聯絡人",
    "Search conversations or contacts" : "搜尋對話或聯絡人"
},
"nplurals=1; plural=0;");
